@@ -6,11 +6,12 @@ from mdpeditor.parameterhelp import extract
 def run_explain(console, explain_string):
 
     if not explain_string:
-        console.print("\nTry explain PARAMETER where PARAMETER is "
+        console.print("\nUse as \n\texplain [italic]PARAMETER \n[/]"
+                      "where [italic]PARAMETER[/] is "
                       "one of these predefined parameter blocks\n")
         block_names = '\n\t'.join(provide.available_parameter_blocks())
         console.print("[bold]\t" + block_names + "[/]")
-        console.print("\nor an .mdp option like [bold]integrator[/].")
+        console.print("\nor an .mdp option like [bold]integrator[/].\n")
         return
 
     explain_string = explain_string.strip()
@@ -31,6 +32,8 @@ def run_explain(console, explain_string):
         pass
     except IndexError:
         pass
+    except ModuleNotFoundError:
+        pass
 
     raise SystemExit(f"[red bold]{explain_string}[/] is neither an "
                      f".mdp option nor a predefined block")
