@@ -3,6 +3,31 @@
 import importlib
 
 
+def mdp_options_list():
+    """Extract All documented .mdp options
+    """
+
+    # debugging help:
+    # with open("./mdpeditor/parameterhelp/mdp-options.rst") as f:
+    #     mdp_options = f.read()
+
+    mdp_options = importlib.resources.read_text(__package__, "mdp-options.rst")
+
+    parameter_tag = "\n.. mdp:: "
+
+    list_of_options = []
+    end = 0
+    # keep searching for parameter_tag in mdp_options until none found
+    # then return
+    while True:
+        try:
+            start = mdp_options.index(parameter_tag, end) + len(parameter_tag)
+            end = mdp_options.index("\n", start)
+            list_of_options += [mdp_options[start:end].strip()]
+        except ValueError:
+            return list_of_options
+
+
 def mdp_section(parameter_name):
     """Extract user guide section about a specific mdp parameter
 
@@ -41,3 +66,6 @@ def mdp_section(parameter_name):
     end = min(next_section_position, next_tag_position)
 
     return mdp_options[start + len(parameter_name): start+end].strip()
+
+
+mdp_options_list()
